# BboxTools
BboxTools is a light weighted lib for bounding box operation mainly aims at helping data pre-processing, post-processing, and visualization for deep learning (especially object and keypoint detection). BboxTools provide easily used bounding box operations such as padding, shifting, scaling bounding boxes, also, visualization tools that can work with numpy and PIL. The bounding boxes can be applied to numpy and pytorch.

## Install
Install from pip:
```
pip install BboxTools
```
